@@ -34,6 +34,8 @@ Example
     AppView.current().pin()
 """
 
+__version__ = "0.2.1"
+
 import platform
 import os
 
@@ -46,5 +48,4 @@ def _check_version():
 if not os.getenv("READTHEDOCS"):
     _check_version()
 
-from .app_view import AppView, get_apps_by_z_order
-from .desktop import VirtualDesktop, get_virtual_desktops
\ No newline at end of file
+from .pyvda import AppView, get_apps_by_z_order, VirtualDesktop, get_virtual_desktops
